# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/transport/generated/sdk/v1/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/transport/generated/sdk/v1/processor.proto',
  package='grebbleFlow.sdk.v1',
  syntax='proto3',
  serialized_options=b'Z<gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/sdk/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7grebble_flow/transport/generated/sdk/v1/processor.proto\x12\x12grebbleFlow.sdk.v1\"J\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04hint\x18\x03 \x01(\t\x12\x12\n\nfield_type\x18\x04 \x01(\t\"\x1c\n\x0cRelationDesc\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa1\x01\n\x04\x44\x65sc\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x31\n\nparameters\x18\x04 \x03(\x0b\x32\x1d.grebbleFlow.sdk.v1.Parameter\x12\x33\n\trelations\x18\x05 \x03(\x0b\x32 .grebbleFlow.sdk.v1.RelationDesc\"(\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"a\n\tProcessor\x12,\n\x07package\x18\x01 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Package\x12&\n\x04\x64\x65sc\x18\x02 \x01(\x0b\x32\x18.grebbleFlow.sdk.v1.Desc\"\x13\n\x11InitProcessorsReq\"F\n\x11InitProcessorsRes\x12\x31\n\nprocessors\x18\x01 \x03(\x0b\x32\x1d.grebbleFlow.sdk.v1.Processor\"c\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"V\n\x0fTransferMessage\x12,\n\x07message\x18\x01 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Message\x12\x15\n\rrelation_name\x18\x02 \x01(\t\"M\n\x0cOnTriggerRes\x12=\n\x10transfer_message\x18\x01 \x01(\x0b\x32#.grebbleFlow.sdk.v1.TransferMessage\"a\n\x0cOnTriggerReq\x12\x11\n\tflow_name\x18\x01 \x01(\t\x12,\n\x07Message\x18\x02 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Message\x12\x10\n\x08settings\x18\x03 \x01(\x0c\x32\xc9\x01\n\x10ProcessorService\x12`\n\x0eInitProcessors\x12%.grebbleFlow.sdk.v1.InitProcessorsReq\x1a%.grebbleFlow.sdk.v1.InitProcessorsRes\"\x00\x12S\n\tOnTrigger\x12 .grebbleFlow.sdk.v1.OnTriggerReq\x1a .grebbleFlow.sdk.v1.OnTriggerRes\"\x00\x30\x01\x42>Z<gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/sdk/v1b\x06proto3'
)




_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='grebbleFlow.sdk.v1.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='grebbleFlow.sdk.v1.Parameter.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='grebbleFlow.sdk.v1.Parameter.hint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_type', full_name='grebbleFlow.sdk.v1.Parameter.field_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=153,
)


_RELATIONDESC = _descriptor.Descriptor(
  name='RelationDesc',
  full_name='grebbleFlow.sdk.v1.RelationDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.RelationDesc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=183,
)


_DESC = _descriptor.Descriptor(
  name='Desc',
  full_name='grebbleFlow.sdk.v1.Desc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='grebbleFlow.sdk.v1.Desc.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='grebbleFlow.sdk.v1.Desc.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='grebbleFlow.sdk.v1.Desc.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='grebbleFlow.sdk.v1.Desc.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='grebbleFlow.sdk.v1.Desc.relations', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=347,
)


_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='grebbleFlow.sdk.v1.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.Package.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='grebbleFlow.sdk.v1.Package.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=389,
)


_PROCESSOR = _descriptor.Descriptor(
  name='Processor',
  full_name='grebbleFlow.sdk.v1.Processor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package', full_name='grebbleFlow.sdk.v1.Processor.package', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desc', full_name='grebbleFlow.sdk.v1.Processor.desc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=488,
)


_INITPROCESSORSREQ = _descriptor.Descriptor(
  name='InitProcessorsReq',
  full_name='grebbleFlow.sdk.v1.InitProcessorsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=509,
)


_INITPROCESSORSRES = _descriptor.Descriptor(
  name='InitProcessorsRes',
  full_name='grebbleFlow.sdk.v1.InitProcessorsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebbleFlow.sdk.v1.InitProcessorsRes.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=581,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='grebbleFlow.sdk.v1.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grebbleFlow.sdk.v1.Message.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='grebbleFlow.sdk.v1.Message.parent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.sdk.v1.Message.attributes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='grebbleFlow.sdk.v1.Message.content_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.sdk.v1.Message.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=682,
)


_TRANSFERMESSAGE = _descriptor.Descriptor(
  name='TransferMessage',
  full_name='grebbleFlow.sdk.v1.TransferMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='grebbleFlow.sdk.v1.TransferMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relation_name', full_name='grebbleFlow.sdk.v1.TransferMessage.relation_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=770,
)


_ONTRIGGERRES = _descriptor.Descriptor(
  name='OnTriggerRes',
  full_name='grebbleFlow.sdk.v1.OnTriggerRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_message', full_name='grebbleFlow.sdk.v1.OnTriggerRes.transfer_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=849,
)


_ONTRIGGERREQ = _descriptor.Descriptor(
  name='OnTriggerReq',
  full_name='grebbleFlow.sdk.v1.OnTriggerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_name', full_name='grebbleFlow.sdk.v1.OnTriggerReq.flow_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Message', full_name='grebbleFlow.sdk.v1.OnTriggerReq.Message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='grebbleFlow.sdk.v1.OnTriggerReq.settings', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=948,
)

_DESC.fields_by_name['parameters'].message_type = _PARAMETER
_DESC.fields_by_name['relations'].message_type = _RELATIONDESC
_PROCESSOR.fields_by_name['package'].message_type = _PACKAGE
_PROCESSOR.fields_by_name['desc'].message_type = _DESC
_INITPROCESSORSRES.fields_by_name['processors'].message_type = _PROCESSOR
_TRANSFERMESSAGE.fields_by_name['message'].message_type = _MESSAGE
_ONTRIGGERRES.fields_by_name['transfer_message'].message_type = _TRANSFERMESSAGE
_ONTRIGGERREQ.fields_by_name['Message'].message_type = _MESSAGE
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['RelationDesc'] = _RELATIONDESC
DESCRIPTOR.message_types_by_name['Desc'] = _DESC
DESCRIPTOR.message_types_by_name['Package'] = _PACKAGE
DESCRIPTOR.message_types_by_name['Processor'] = _PROCESSOR
DESCRIPTOR.message_types_by_name['InitProcessorsReq'] = _INITPROCESSORSREQ
DESCRIPTOR.message_types_by_name['InitProcessorsRes'] = _INITPROCESSORSRES
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['TransferMessage'] = _TRANSFERMESSAGE
DESCRIPTOR.message_types_by_name['OnTriggerRes'] = _ONTRIGGERRES
DESCRIPTOR.message_types_by_name['OnTriggerReq'] = _ONTRIGGERREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

RelationDesc = _reflection.GeneratedProtocolMessageType('RelationDesc', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONDESC,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.RelationDesc)
  })
_sym_db.RegisterMessage(RelationDesc)

Desc = _reflection.GeneratedProtocolMessageType('Desc', (_message.Message,), {
  'DESCRIPTOR' : _DESC,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Desc)
  })
_sym_db.RegisterMessage(Desc)

Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Package)
  })
_sym_db.RegisterMessage(Package)

Processor = _reflection.GeneratedProtocolMessageType('Processor', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSOR,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Processor)
  })
_sym_db.RegisterMessage(Processor)

InitProcessorsReq = _reflection.GeneratedProtocolMessageType('InitProcessorsReq', (_message.Message,), {
  'DESCRIPTOR' : _INITPROCESSORSREQ,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.InitProcessorsReq)
  })
_sym_db.RegisterMessage(InitProcessorsReq)

InitProcessorsRes = _reflection.GeneratedProtocolMessageType('InitProcessorsRes', (_message.Message,), {
  'DESCRIPTOR' : _INITPROCESSORSRES,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.InitProcessorsRes)
  })
_sym_db.RegisterMessage(InitProcessorsRes)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Message)
  })
_sym_db.RegisterMessage(Message)

TransferMessage = _reflection.GeneratedProtocolMessageType('TransferMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERMESSAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.TransferMessage)
  })
_sym_db.RegisterMessage(TransferMessage)

OnTriggerRes = _reflection.GeneratedProtocolMessageType('OnTriggerRes', (_message.Message,), {
  'DESCRIPTOR' : _ONTRIGGERRES,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.OnTriggerRes)
  })
_sym_db.RegisterMessage(OnTriggerRes)

OnTriggerReq = _reflection.GeneratedProtocolMessageType('OnTriggerReq', (_message.Message,), {
  'DESCRIPTOR' : _ONTRIGGERREQ,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.OnTriggerReq)
  })
_sym_db.RegisterMessage(OnTriggerReq)


DESCRIPTOR._options = None

_PROCESSORSERVICE = _descriptor.ServiceDescriptor(
  name='ProcessorService',
  full_name='grebbleFlow.sdk.v1.ProcessorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=951,
  serialized_end=1152,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitProcessors',
    full_name='grebbleFlow.sdk.v1.ProcessorService.InitProcessors',
    index=0,
    containing_service=None,
    input_type=_INITPROCESSORSREQ,
    output_type=_INITPROCESSORSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnTrigger',
    full_name='grebbleFlow.sdk.v1.ProcessorService.OnTrigger',
    index=1,
    containing_service=None,
    input_type=_ONTRIGGERREQ,
    output_type=_ONTRIGGERRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSORSERVICE)

DESCRIPTOR.services_by_name['ProcessorService'] = _PROCESSORSERVICE

# @@protoc_insertion_point(module_scope)



import logging
from concurrent import futures

import grpc
from grebble_flow.transport.generated.sdk.v1 import processor_pb2_grpc
from grebble_flow.transport.service.processor import ProcessorService


def start_server(port):
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    processor_pb2_grpc.add_ProcessorServiceServicer_to_server(ProcessorService(), server)
    server.add_insecure_port(f"[::]:{port}")
    server.start()
    logging.info("Server started")
    server.wait_for_termination()



def exec_code(code, session):
    the_code = (
        """
def factorial(session):
    """
        + code
        + """
return_me = factorial(session)
"""
    )
    loc = {}
    exec(the_code, {"session": session}, loc)
    return_workaround = loc["return_me"]
    return return_workaround



from grebble_flow.transport.generated.sdk.v1.processor_pb2 import Message


class Session:
    def __init__(self, msg: Message):
        self.msg = msg

    def get_message(self):
        return self.msg



from dataclasses import dataclass
from typing import Any

from dataclasses_json import dataclass_json
from executor.execsdk import exec_code
from grebble_flow.processors.base import BaseFlowProcessor
from grebble_flow.processors import models
from grebble_flow.processors.session import Session


@dataclass
@dataclass_json
class SimpleFlowSettings:
    """
    Args:
       code (string): Python code
    """

    code: str

    def __init__(self, code):
        self.code = code


class SimpleProcessor(BaseFlowProcessor):
    title = "Python code executor"
    description = "Python code executor"
    name = "python-code-executor"
    group = "python"
    relations = [models.RelationDesc("success")]
    settings = SimpleFlowSettings

    def on_trigger(
        self, session: Session, settings: SimpleFlowSettings, *args, **kwargs
    ):
        return exec_code(settings.code, session)
        # exec(code, {"session": session})



from dataclasses import dataclass
from typing import List


@dataclass
class Message:
    id: str
    parent_id: str
    attributes: dict
    content_type: str
    content: bytes

    def __init__(
        self,
        id: str,
        parent_id: str,
        attributes: dict,
        content_type: str,
        content: bytes,
    ):
        self.id = id
        self.parent_id = parent_id
        self.attributes = attributes
        self.content_type = content_type
        self.content = content


@dataclass
class Transfer:
    message: Message
    relation_name: str

    def __init__(self, message: Message, relation_name: str):
        self.message = message
        self.relation_name = relation_name


@dataclass
class Package:
    name: str
    version: str

    def __init__(self, name: str, version: str):
        self.name = name
        self.version = version


@dataclass
class Parameter:
    name: str
    title: str
    hint: str
    field_type: str

    def __init__(self, name: str, title: str, hint: str, field_type: str):
        self.name = name
        self.title = title
        self.hint = hint
        self.field_type = field_type


@dataclass
class RelationDesc:
    name: str

    def __init__(self, name: str):
        self.name = name


@dataclass
class Desc:
    title: str
    description: str
    group: str
    parameters: List[Parameter]
    relations: List[RelationDesc]

    def __init__(
        self,
        title: str,
        description: str,
        group: str,
        parameters: List[Parameter],
        relations: List[RelationDesc],
    ):
        self.title = title
        self.description = description
        self.group = group
        self.parameters = parameters
        self.relations = relations



import json

from grebble_flow.managment.manager import FlowManager
from grebble_flow.transport.generated.sdk.v1 import processor_pb2_grpc
from grebble_flow.transport.generated.sdk.v1.processor_pb2 import (
    InitProcessorsRes,
    Processor,
    Desc,
    Parameter,
    RelationDesc,
    Package,
    Message,
    OnTriggerRes,
    TransferMessage,
)
from processors import models
from grebble_flow.processors.session import Session


class ProcessorService(processor_pb2_grpc.ProcessorServiceServicer):
    def __init__(self, *args, **kwargs):
        self.flow_manager = FlowManager()

    def InitProcessors(self, request, context):
        processors = []
        for processor_class in self.flow_manager.get_all_processor_classes():
            processor = self.flow_manager.init_processor(processor_class)
            processor_desc: models.Desc = processor.get_description()
            package: models.Package = processor.get_package()
            parameters = [
                Parameter(
                    name=x.name, title=x.title, hint=x.hint, field_type=x.field_type,
                )
                for x in processor_desc.parameters
            ]
            p = Processor(
                desc=Desc(
                    title=processor_desc.title,
                    description=processor_desc.description,
                    group=processor_desc.group,
                    parameters=parameters,
                    relations=[
                        RelationDesc(name=x.name,) for x in processor_desc.relations
                    ],
                ),
                package=Package(name=package.name, version=package.version),
            )
            processors += [p]

        resp = InitProcessorsRes(processors=processors)
        return resp

    def OnTrigger(self, request, context):
        flow_name = request.flow_name
        processor = self.flow_manager.find_processor_instance_by_name(flow_name)

        m: models.Message = None
        if request.Message is not None:

            attributes = request.Message.attributes

            try:
                attributes = json.loads(request.Message.attributes)
            except:
                pass

            m = models.Message(
                id=request.Message.id,
                parent_id=request.Message.parent_id,
                content_type=request.Message.content_type,
                attributes=attributes,
                content=request.Message.content,
            )

        settings = processor.settings.from_json(request.settings.decode("utf-8"))
        for item in processor.on_trigger(Session(m), settings):
            relation_name = item[1]
            message = item[0]
            attr = json.dumps(message.attributes)
            transfer_message = TransferMessage(
                relation_name=relation_name,
                message=Message(
                    id=message.id,
                    parent_id=message.parent_id,
                    content_type=message.content_type,
                    attributes=bytes(attr, "utf-8"),
                    content=message.content,
                ),
            )
            yield OnTriggerRes(transfer_message=transfer_message)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from grebble_flow.transport.generated.sdk.v1 import processor_pb2 as grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2


class ProcessorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitProcessors = channel.unary_unary(
                '/grebbleFlow.sdk.v1.ProcessorService/InitProcessors',
                request_serializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsReq.SerializeToString,
                response_deserializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsRes.FromString,
                )
        self.OnTrigger = channel.unary_stream(
                '/grebbleFlow.sdk.v1.ProcessorService/OnTrigger',
                request_serializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerReq.SerializeToString,
                response_deserializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerRes.FromString,
                )


class ProcessorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InitProcessors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProcessorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitProcessors': grpc.unary_unary_rpc_method_handler(
                    servicer.InitProcessors,
                    request_deserializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsReq.FromString,
                    response_serializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsRes.SerializeToString,
            ),
            'OnTrigger': grpc.unary_stream_rpc_method_handler(
                    servicer.OnTrigger,
                    request_deserializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerReq.FromString,
                    response_serializer=grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'grebbleFlow.sdk.v1.ProcessorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProcessorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InitProcessors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/grebbleFlow.sdk.v1.ProcessorService/InitProcessors',
            grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsReq.SerializeToString,
            grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.InitProcessorsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/grebbleFlow.sdk.v1.ProcessorService/OnTrigger',
            grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerReq.SerializeToString,
            grebble__flow_dot_transport_dot_generated_dot_sdk_dot_v1_dot_processor__pb2.OnTriggerRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Any

from docstring_parser import parser

from grebble_flow.processors import models
from .session import Session


class BaseFlowProcessor:
    def get_package(self) -> models.Package:
        return models.Package(self.name, "")

    def get_description(self) -> models.Desc:
        parameters = []

        docs = parser.parse(self.settings.__doc__)
        for key, value in self.settings.__annotations__.items():
            param_doc = [x for x in docs.params if x.arg_name == key]
            description = ""
            field_type = "str"
            if len(param_doc) > 0:
                param_doc = param_doc[0]
                description = param_doc.description
                field_type = param_doc.type_name

            parameters += [models.Parameter(key, description, description, field_type)]
        return models.Desc(
            title=self.title,
            description=self.description,
            group=self.group,
            relations=self.relations,
            parameters=parameters,
        )

    def on_trigger(self, s: Session, settings: Any, *args, **kwargs):
        raise NotImplemented()
